@@ -55,7 +55,7 @@
 #define DIALOG_NEW_CUSTOMER_CM_CLASS "dialog-new-customer"
 #define DIALOG_EDIT_CUSTOMER_CM_CLASS "dialog-edit-customer"
 
-#define GCONF_SECTION_SEARCH "dialogs/business/customer_search"
+#define GNC_PREFS_GROUP_SEARCH "dialogs.business.customer-search"
 
 void gnc_customer_taxtable_check_cb (GtkToggleButton *togglebutton,
                                      gpointer user_data);
@@ -390,7 +390,7 @@ gnc_customer_window_cancel_cb (GtkWidget *widget, gpointer data)
 void
 gnc_customer_window_help_cb (GtkWidget *widget, gpointer data)
 {
-    gnc_gnome_help(HF_HELP, HL_USAGE);
+    gnc_gnome_help(HF_HELP, HL_USAGE_CUSTOMER);
 }
 
 void
@@ -957,7 +957,7 @@ gnc_customer_search (GncCustomer *start, QofBook *book)
     return gnc_search_dialog_create (type, _("Find Customer"),
                                      params, columns, q, q2, buttons, NULL,
                                      new_customer_cb, sw, free_userdata_cb,
-                                     GCONF_SECTION_SEARCH, NULL);
+                                     GNC_PREFS_GROUP_SEARCH, NULL);
 }
 
 GNCSearchWindow *
