@@ -50,7 +50,7 @@
 #define DIALOG_NEW_VENDOR_CM_CLASS "dialog-new-vendor"
 #define DIALOG_EDIT_VENDOR_CM_CLASS "dialog-edit-vendor"
 
-#define GCONF_SECTION_SEARCH "dialogs/business/vendor_search"
+#define GNC_PREFS_GROUP_SEARCH "dialogs.business.vendor-search"
 
 void gnc_vendor_taxtable_check_cb (GtkToggleButton *togglebutton, gpointer user_data);
 void gnc_vendor_window_ok_cb (GtkWidget *widget, gpointer data);
@@ -261,7 +261,7 @@ gnc_vendor_window_cancel_cb (GtkWidget *widget, gpointer data)
 void
 gnc_vendor_window_help_cb (GtkWidget *widget, gpointer data)
 {
-    gnc_gnome_help(HF_HELP, HL_USAGE);
+    gnc_gnome_help(HF_HELP, HL_USAGE_VENDOR);
 }
 
 void
@@ -759,7 +759,7 @@ gnc_vendor_search (GncVendor *start, QofBook *book)
     return gnc_search_dialog_create (type, _("Find Vendor"),
                                      params, columns, q, q2, buttons, NULL,
                                      new_vendor_cb, sw, free_vendor_cb,
-                                     GCONF_SECTION_SEARCH, NULL);
+                                     GNC_PREFS_GROUP_SEARCH, NULL);
 }
 
 GNCSearchWindow *
