@@ -909,7 +909,7 @@ gnc_search_dialog_book_option_changed (gpointer new_val, gpointer user_data)
 static void
 gnc_search_dialog_add_criterion (GNCSearchWindow *sw)
 {
-    GNCSearchCoreType *new;
+    GNCSearchCoreType *new_sct;
 
     /* First, make sure that the last criterion is ok */
     if (sw->crit_list)
@@ -926,16 +926,16 @@ gnc_search_dialog_add_criterion (GNCSearchWindow *sw)
         gtk_widget_hide(sw->match_all_label);
     }
     /* create a new criterion element */
-    new = gnc_search_core_type_new_type_name
+    new_sct = gnc_search_core_type_new_type_name
           (gnc_search_param_get_param_type (sw->last_param));
 
-    if (new)
+    if (new_sct)
     {
         struct _crit_data *data;
         GtkWidget *w;
         int rows;
 
-        w = get_element_widget (sw, new);
+        w = get_element_widget (sw, new_sct);
         data = g_object_get_data (G_OBJECT (w), "data");
         sw->crit_list = g_list_append (sw->crit_list, data);
 
@@ -943,8 +943,8 @@ gnc_search_dialog_add_criterion (GNCSearchWindow *sw)
         gtk_table_resize (GTK_TABLE (sw->criteria_table), rows + 1, 2);
         attach_element (w, sw, rows);
 
-        gnc_search_core_type_grab_focus (new);
-        gnc_search_core_type_editable_enters (new);
+        gnc_search_core_type_grab_focus (new_sct);
+        gnc_search_core_type_editable_enters (new_sct);
     }
 }
 
@@ -1016,50 +1016,50 @@ close_handler (gpointer data)
 static const gchar *
 type_label_to_new_button(const gchar* type_label)
 {
-    if (g_strcmp0(type_label, "Bill") == 0)
+    if (g_strcmp0(type_label, _("Bill")) == 0)
     {
         return _("New Bill");
     }
-    else if (g_strcmp0(type_label, "Customer") == 0)
+    else if (g_strcmp0(type_label, _("Customer")) == 0)
     {
         return _("New Customer");
     }
-    else if (g_strcmp0(type_label, "Employee") == 0)
+    else if (g_strcmp0(type_label, _("Employee")) == 0)
     {
         return _("New Employee");
     }
-    else if (g_strcmp0(type_label, "Expense Voucher") == 0)
+    else if (g_strcmp0(type_label, _("Expense Voucher")) == 0)
     {
         return _("New Expense Voucher");
     }
-    else if (g_strcmp0(type_label, "Invoice") == 0)
+    else if (g_strcmp0(type_label, _("Invoice")) == 0)
     {
         return _("New Invoice");
     }
-    else if (g_strcmp0(type_label, "Job") == 0)
+    else if (g_strcmp0(type_label, _("Job")) == 0)
     {
         return _("New Job");
     }
-    else if (g_strcmp0(type_label, "Order") == 0)
+    else if (g_strcmp0(type_label, _("Order")) == 0)
     {
         return _("New Order");
     }
-    else if (g_strcmp0(type_label, "Transaction") == 0)
+    else if (g_strcmp0(type_label, _("Transaction")) == 0)
     {
         return _("New Transaction");
     }
-    else if (g_strcmp0(type_label, "Split") == 0)
+    else if (g_strcmp0(type_label, _("Split")) == 0)
     {
         return _("New Split");
     }
-    else if (g_strcmp0(type_label, "Vendor") == 0)
+    else if (g_strcmp0(type_label, _("Vendor")) == 0)
     {
         return _("New Vendor");
     }
     else
     {
         PWARN("No translatable new-button label found for search type \"%s\", please add one into dialog-search.c!", type_label);
-        return _("New item");
+        return Q_("Item represents an unknown object type (in the sense of bill, customer, invoice, transaction, split,...)|New item");
     }
 }
 
