@@ -1271,6 +1271,7 @@ void
 schedXact_editor_create_freq_sel( GncSxEditorDialog *sxed )
 {
     GtkBox *b;
+    GtkWidget *example_cal_scrolled_win = NULL;
 
     b = GTK_BOX(gtk_builder_get_object (sxed->builder, "gncfreq_hbox"));
 
@@ -1281,16 +1282,25 @@ schedXact_editor_create_freq_sel( GncSxEditorDialog *sxed )
     g_signal_connect( sxed->gncfreq, "changed",
                       G_CALLBACK(gnc_sxed_freq_changed),
                       sxed );
-    gtk_container_add( GTK_CONTAINER(b), GTK_WIDGET(sxed->gncfreq) );
+
+    gtk_box_pack_start(GTK_BOX(b), GTK_WIDGET(sxed->gncfreq), TRUE, TRUE, 0);
 
     b = GTK_BOX(gtk_builder_get_object (sxed->builder, "example_cal_hbox" ));
+
+    example_cal_scrolled_win = gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(example_cal_scrolled_win),
+                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+    gtk_box_pack_start(GTK_BOX(b), example_cal_scrolled_win, TRUE, TRUE, 0);
+
     sxed->dense_cal_model = gnc_dense_cal_store_new(EX_CAL_NUM_MONTHS * 31);
     sxed->example_cal = GNC_DENSE_CAL(gnc_dense_cal_new_with_model(GNC_DENSE_CAL_MODEL(sxed->dense_cal_model)));
     g_assert(sxed->example_cal);
     gnc_dense_cal_set_num_months( sxed->example_cal, EX_CAL_NUM_MONTHS );
     gnc_dense_cal_set_months_per_col( sxed->example_cal, EX_CAL_MO_PER_COL );
-    gtk_container_add( GTK_CONTAINER(b), GTK_WIDGET(sxed->example_cal) );
-    gtk_widget_show( GTK_WIDGET(sxed->example_cal) );
+
+    gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(example_cal_scrolled_win),
+                                          GTK_WIDGET(sxed->example_cal));
+    gtk_widget_show_all( example_cal_scrolled_win );
 }
 
 
@@ -1661,6 +1671,7 @@ sxed_excal_update_adapt_cb(GtkObject *o, gpointer ud)
 void
 on_sx_check_toggled_cb (GtkWidget *togglebutton, gpointer user_data)
 {
+    GtkWidget *widget_auto;
     GtkWidget *widget_notify;
     GHashTable *table;
 
@@ -1669,9 +1680,21 @@ on_sx_check_toggled_cb (GtkWidget *togglebutton, gpointer user_data)
 
     /* We need to use the hash table to find the required widget to activate. */
     table = g_object_get_data(G_OBJECT(user_data), "prefs_widget_hash");
+
+    /* "Auto-create" enables "notify before creation" setting */
+    widget_auto = g_hash_table_lookup(table, "pref/" GNC_PREFS_GROUP_SXED "/" GNC_PREF_CREATE_AUTO);
     widget_notify = g_hash_table_lookup(table, "pref/" GNC_PREFS_GROUP_SXED "/" GNC_PREF_NOTIFY);
 
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)))
+    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget_auto)))
+        gtk_widget_set_sensitive(widget_notify, TRUE);
+    else
+        gtk_widget_set_sensitive(widget_notify, FALSE);
+
+    /* "Run when opened" enables "show notification window" setting */
+    widget_auto = g_hash_table_lookup(table, "pref/" GNC_PREFS_GROUP_STARTUP "/" GNC_PREF_RUN_AT_FOPEN);
+    widget_notify = g_hash_table_lookup(table, "pref/" GNC_PREFS_GROUP_STARTUP "/" GNC_PREF_SHOW_AT_FOPEN);
+
+    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget_auto)))
         gtk_widget_set_sensitive(widget_notify, TRUE);
     else
         gtk_widget_set_sensitive(widget_notify, FALSE);
