@@ -233,11 +233,16 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
 {
     GtkTreeIter iter;
     gboolean valid, row_deleted, row_fixed;
-    gchar *id, *date_opened, *date_posted, *owner_id, *date, *quantity, *price;
+    gchar *id, *date_opened, *date_posted, *due_date, *owner_id, *date, *quantity, *price;
     GString *prev_id, *prev_date_opened, *prev_date_posted, *prev_owner_id, *prev_date;	// needed to fix multi line invoices
     guint dummy;
     gint row = 1;
+    const gchar* date_format_string = qof_date_format_get_string (qof_date_format_get()); // Get the user set date format string
+    
+    
+    //date_format_string = qof_date_format_get_string (qof_date_format_get());	
 
+    DEBUG("date_format_string: %s",date_format_string);
     // allow the call to this function with only GtkListeStore* specified
     if (!fixed)
         fixed = &dummy;
@@ -265,6 +270,7 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
                             ID, &id,
                             DATE_OPENED, &date_opened,
                             DATE_POSTED, &date_posted,
+                            DUE_DATE, &due_date,
                             OWNER_ID, &owner_id,
                             DATE, &date,
                             QUANTITY, &quantity, PRICE, &price, -1);
@@ -279,6 +285,7 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
                                     _("ROW %d DELETED, PRICE_NOT_SET: id=%s\n"),
                                     row, id);
         }
+        // TODO: QTY get set to 1 later if field is empty.  Delete this section?
         else if (strlen (quantity) == 0)
         {
             // invalid row (no quantity given)
@@ -289,7 +296,7 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
                                     row, id);
         }
         else
-        {
+        {   // TODO: If id is empty get the next one in the series.  Bug 731105 
             if (strlen (id) == 0)
             {
                 // no invoice id specified
@@ -324,7 +331,7 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
         {
             // the row is valid (price and id are valid)
 
-            if (strlen (date_opened) == 0)
+            if(!isDateValid(date_opened))
             {
                 if (prev_date_opened->len == 0)
                 {
@@ -333,7 +340,7 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
                     GDate date;
                     g_date_clear (&date, 1);
                     gnc_gdate_set_today (&date);
-                    g_date_strftime (temp, 20, "%x", &date);	// create a locale specific date string
+                    g_date_strftime (temp, 20, date_format_string, &date);	// Create a user specified date string.
                     g_string_assign (prev_date_opened, temp);
                 }
                 // fix this by using the previous date_opened value (multi line invoice)
@@ -349,8 +356,8 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
 
             // date_opened is valid
 
-            if (strlen (date_posted) == 0)
-            {
+             if(!isDateValid(date_posted))
+             {
                 if (prev_date_posted->len == 0)
                 {
                     // this invoice will have to get posted manually
@@ -370,13 +377,25 @@ gnc_bi_import_fix_bis (GtkListStore * store, guint * fixed, guint * deleted,
             }
 
             // date_posted is valid
-
+            /*
+            // Check if due date is valid.  Set it to date_posted if not valid or missing.
+            if(!isDateValid(due_date))
+            {
+                gtk_list_store_set (store, &iter, DUE_DATE,
+                                        date_posted, -1);
+                row_fixed = TRUE;
+                
+            }
+            
+            // due_date is valid
+            */
             if (strlen (quantity) == 0)
             {
                 // quantity is unset => set to 1
                 gtk_list_store_set (store, &iter, QUANTITY, "1", -1);
                 row_fixed = TRUE;
             }
+            
 
             // quantity is valid
 
@@ -488,7 +507,7 @@ void
 gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
                           guint * n_invoices_created,
                           guint * n_invoices_updated,
-                          gchar * type, gchar * open_mode )
+                          gchar * type, gchar * open_mode, GString * info)
 {
     gboolean valid;
     GtkTreeIter iter;
@@ -501,14 +520,17 @@ gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
     GncInvoice *invoice;
     GncEntry *entry;
     gint day, month, year;
-    gnc_numeric n;
+    gnc_numeric value;
     GncOwner *owner;
     Account *acc;
     enum update {YES = GTK_RESPONSE_YES, NO = GTK_RESPONSE_NO} update;
     GtkWidget *dialog;
     Timespec today;
     InvoiceWindow *iw;
-
+    gchar *new_id = NULL;
+    gint64 denom = 0;
+    gnc_commodity *currency;
+    
     // these arguments are needed
     g_return_if_fail (store && book);
     // logic of this function only works for bills or invoices
@@ -565,12 +587,12 @@ gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
             invoice = gnc_search_bill_on_id (book, id);
         else if (g_ascii_strcasecmp (type, "INVOICE") == 0)
             invoice = gnc_search_invoice_on_id (book, id);
-        PINFO( "Existing %s ID: %s\n", type, gncInvoiceGetID(invoice));
+        DEBUG( "Existing %s ID: %s\n", type, gncInvoiceGetID(invoice));
 
         // If the search is empty then there is no existing invoice so make a new one
         if (invoice == NULL)
         {
-             PINFO( "Creating a new : %s\n", type );
+             DEBUG( "Creating a new : %s\n", type );
             // new invoice
             invoice = gncInvoiceCreate (book);
             /* Protect against thrashing the DB and trying to write the invoice
@@ -673,6 +695,9 @@ gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
 
         // add entry to invoice/bill
         entry = gncEntryCreate (book);
+        gncEntryBeginEdit(entry);
+        currency = gncInvoiceGetCurrency(invoice);
+        if (currency) denom = gnc_commodity_get_fraction(currency);
         // FIXME: Must check for the return value of qof_scan_date!
         qof_scan_date (date, &day, &month, &year);
         {
@@ -685,102 +710,101 @@ gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
         gncEntrySetDescription (entry, desc);
         gncEntrySetAction (entry, action);
 
-        n = gnc_numeric_zero ();
-        gnc_exp_parser_parse (quantity, &n, NULL);
-        gncEntrySetQuantity (entry, n);
+        gnc_exp_parser_parse (quantity, &value, NULL);
+        gncEntrySetQuantity (entry, value);
         acc = gnc_account_lookup_for_register (gnc_get_current_root_account (),
                                                account);
         
         if (g_ascii_strcasecmp (type, "BILL") == 0)
         {
             gncEntrySetBillAccount (entry, acc);
-            n = gnc_numeric_zero ();
-            gnc_exp_parser_parse (price, &n, NULL);
-            gncEntrySetBillPrice (entry, n);
+            gnc_exp_parser_parse (price, &value, NULL);
+            value = gnc_numeric_convert (value, denom, GNC_HOW_RND_NEVER);
+            gncEntrySetBillPrice (entry, value);
             gncEntrySetBillTaxable (entry, text2bool (taxable));
             gncEntrySetBillTaxIncluded (entry, text2bool (taxincluded));
-            gncEntrySetBillTaxTable (entry,
-                                     gncTaxTableLookupByName (book, tax_table));
-            n = gnc_numeric_zero ();
-            gnc_exp_parser_parse (discount, &n, NULL);
+            gncEntrySetBillTaxTable (entry, gncTaxTableLookupByName (book, tax_table));
+            gncEntryCommitEdit(entry);
             gncBillAddEntry (invoice, entry);
         }
         else if (g_ascii_strcasecmp (type, "INVOICE") == 0)
         {
             gncEntrySetNotes (entry, notes);
             gncEntrySetInvAccount (entry, acc);
-            n = gnc_numeric_zero ();
-            gnc_exp_parser_parse (price, &n, NULL);
-            gncEntrySetInvPrice (entry, n);
+            gnc_exp_parser_parse (price, &value, NULL);
+            value = gnc_numeric_convert (value, denom, GNC_HOW_RND_NEVER);
+            gncEntrySetInvPrice (entry, value);
             gncEntrySetInvTaxable (entry, text2bool (taxable));
             gncEntrySetInvTaxIncluded (entry, text2bool (taxincluded));
-            gncEntrySetInvTaxTable (entry,
-                                    gncTaxTableLookupByName (book, tax_table));
-            n = gnc_numeric_zero ();
-            gnc_exp_parser_parse (discount, &n, NULL);
-            gncEntrySetInvDiscount (entry, n);
+            gncEntrySetInvTaxTable (entry, gncTaxTableLookupByName (book, tax_table));
+            gnc_exp_parser_parse (discount, &value, NULL);
+            value = gnc_numeric_convert (value, denom, GNC_HOW_RND_NEVER);
+            gncEntrySetInvDiscount (entry, value);
             gncEntrySetInvDiscountType (entry, text2disc_type (disc_type));
             gncEntrySetInvDiscountHow (entry, text2disc_how (disc_how));
+            gncEntryCommitEdit(entry);
             gncInvoiceAddEntry (invoice, entry);
         }
         valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
 
         // handle auto posting of invoices
+    
+        
+        if (valid)
+            gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, ID, &new_id, -1);
+        if (g_strcmp0 (id, new_id) != 0)
         {
-            gchar *new_id = NULL;
-            if (valid)
-                gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, ID, &new_id, -1);
-            if (g_strcmp0 (id, new_id) != 0)
+            // the next invoice id is different => try to autopost this invoice
+            if (qof_scan_date (date_posted, &day, &month, &year))
             {
-                // the next invoice id is different => try to autopost this invoice
-                if (qof_scan_date (date_posted, &day, &month, &year))
-                {
-                    // autopost this invoice
-                    gboolean auto_pay;
-                    Timespec d1, d2;
+                // autopost this invoice
+                gboolean auto_pay;
+                Timespec d1, d2;
 
-                    if (g_ascii_strcasecmp (type, "INVOICE") == 0)
-                        auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_INVOICE, GNC_PREF_AUTO_PAY);
-                    else
-                        auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_BILL, GNC_PREF_AUTO_PAY);
+                if (g_ascii_strcasecmp (type, "INVOICE") == 0)
+                    auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_INVOICE, GNC_PREF_AUTO_PAY);
+                else
+                    auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_BILL, GNC_PREF_AUTO_PAY);
 
-                    d1 = gnc_dmy2timespec (day, month, year);
-                    // FIXME: Must check for the return value of qof_scan_date!
-                    qof_scan_date (due_date, &day, &month, &year);	// obtains the due date, or leaves it at date_posted
-                    d2 = gnc_dmy2timespec (day, month, year);
-                    acc = gnc_account_lookup_for_register
-                          (gnc_get_current_root_account (), account_posted);
-                    gncInvoicePostToAccount (invoice, acc, &d1, &d2,
-                                             memo_posted,
-                                             text2bool (accumulatesplits),
-                                             auto_pay);
-                }
+                d1 = gnc_dmy2timespec (day, month, year);
+                // FIXME: Must check for the return value of qof_scan_date!
+                qof_scan_date (due_date, &day, &month, &year);	// obtains the due date, or leaves it at date_posted
+                d2 = gnc_dmy2timespec (day, month, year);
+                acc = gnc_account_lookup_for_register
+                      (gnc_get_current_root_account (), account_posted);
+                gncInvoicePostToAccount (invoice, acc, &d1, &d2,
+                                         memo_posted,
+                                         text2bool (accumulatesplits),
+                                         auto_pay);
             }
-            g_free (new_id);
-        }
 
-        // cleanup
-        g_free (id);
-        g_free (date_opened);
-        g_free (owner_id);
-        g_free (billing_id);
-        g_free (notes);
-        g_free (date);
-        g_free (desc);
-        g_free (action);
-        g_free (account);
-        g_free (quantity);
-        g_free (price);
-        g_free (disc_type);
-        g_free (disc_how);
-        g_free (discount);
-        g_free (taxable);
-        g_free (taxincluded);
-        g_free (tax_table);
-        g_free (date_posted);
-        g_free (due_date);
-        g_free (account_posted);
-        g_free (memo_posted);
-        g_free (accumulatesplits);
+        }
+        
+        
     }
+    // cleanup
+    g_free (new_id);
+    g_free (id);
+    g_free (date_opened);
+    g_free (owner_id);
+    g_free (billing_id);
+    g_free (notes);
+    g_free (date);
+    g_free (desc);
+    g_free (action);
+    g_free (account);
+    g_free (quantity);
+    g_free (price);
+    g_free (disc_type);
+    g_free (disc_how);
+    g_free (discount);
+    g_free (taxable);
+    g_free (taxincluded);
+    g_free (tax_table);
+    g_free (date_posted);
+    g_free (due_date);
+    g_free (account_posted);
+    g_free (memo_posted);
+    g_free (accumulatesplits);
+    
 }
