@@ -323,7 +323,7 @@
 ;; Return a list of (printed? value odd-row?)
 ;;
 (define (add-txn-row table txn acc column-vector odd-row? printed?
-             inv-str reverse? start-date total)
+             reverse? start-date total)
   (let* ((type (xaccTransGetTxnType txn))
      (date (gnc-transaction-get-date-posted txn))
      (due-date #f)
@@ -338,12 +338,12 @@
         (gnc:make-html-text
          (gnc:html-markup-anchor
           (gnc:invoice-anchor-text invoice)
-          inv-str))
-        inv-str))
+          (gncInvoiceGetTypeString invoice)))
+        (_ "Unknown")))
        ((equal? type TXN-TYPE-PAYMENT)
         (gnc:make-html-text
 	 (gnc:html-markup-anchor
-	  (gnc:split-anchor-text split) (_ "Payment, thank you"))))
+	  (gnc:split-anchor-text split) (_ "Payment"))))
        (else (_ "Unknown"))))
      )
 
@@ -388,8 +388,6 @@
     (credit (gnc-numeric-zero))
     (currency (gnc-default-currency)) ;XXX
     (table (gnc:make-html-table))
-    (inv-str (gnc:option-value (gnc:lookup-option options "__reg"
-                              "inv-str")))
     (reverse? (gnc:option-value (gnc:lookup-option options "__reg"
                               "reverse?"))))
 
@@ -409,7 +407,7 @@
         (or (equal? type TXN-TYPE-INVOICE)
         (equal? type TXN-TYPE-PAYMENT))
         (let ((result (add-txn-row table txn acc used-columns odd-row? printed?
-                       inv-str reverse? start-date total)))
+                       reverse? start-date total)))
 
           (set! printed? (car result))
           (if (and printed? total)
@@ -435,22 +433,29 @@
             (_ "Period Totals"))
            '())
 
-    ; This is hard-coded to expect 'debits' to follow 'credits'
-    (let ((row-contents '())
-        (credit-span (credit-col used-columns))
-        (debit-span
-        (if (credit-col used-columns) 1 (debit-col used-columns))))
+     (let ((row-contents '())
+         (pre-span 0))
 
-    ; HTML gets generated in reverse order
-    (if (debit-col used-columns) (addto! row-contents
-        (gnc:make-html-table-cell/size/markup
-        1 debit-span "total-number-cell"
-        (gnc:make-gnc-monetary currency debit))))
-    (if (credit-col used-columns) (addto! row-contents
-        (gnc:make-html-table-cell/size/markup
-        1 credit-span "total-number-cell"
-        (gnc:make-gnc-monetary currency credit))))
-    row-contents))))
+      ; HTML gets generated in reverse order
+      (if (value-col used-columns) (addto! row-contents
+          (gnc:make-html-table-cell/size/markup
+          1 1 "total-number-cell"
+          (gnc:make-gnc-monetary currency (gnc-numeric-add-fixed credit debit)))))
+      (if (debit-col used-columns) (addto! row-contents
+          (gnc:make-html-table-cell/size/markup
+          1 1 "total-number-cell"
+          (gnc:make-gnc-monetary currency debit))))
+      (if (credit-col used-columns) (addto! row-contents
+          (gnc:make-html-table-cell/size/markup
+          1 1 "total-number-cell"
+          (gnc:make-gnc-monetary currency credit))))
+      (if (memo-col used-columns) (set! pre-span (+ pre-span 1)))
+      (if (type-col used-columns) (set! pre-span (+ pre-span 1)))
+      (if (num-col used-columns) (set! pre-span (+ pre-span 1)))
+      (if (date-due-col used-columns) (set! pre-span (+ pre-span 1)))
+      (if (date-col used-columns) (set! pre-span (+ pre-span 1)))
+      (if (>= pre-span 2) (addto! row-contents (gnc:make-html-table-cell/size 1 (- pre-span 1) "")))
+     row-contents))))
 
     (if (value-col used-columns)
     (gnc:html-table-append-row/markup! 
@@ -477,16 +482,13 @@
 
     table))
 
-(define (options-generator acct-type-list owner-type inv-str reverse?)
+(define (options-generator acct-type-list owner-type reverse?)
 
   (define gnc:*report-options* (gnc:new-options))
 
   (define (gnc:register-inv-option new-option)
    (gnc:register-option gnc:*report-options* new-option))
 
-  (gnc:register-inv-option
-   (gnc:make-internal-option "__reg" "inv-str" inv-str))
-
   (gnc:register-inv-option
    (gnc:make-simple-boolean-option "__reg" "reverse?" "" "" reverse?))
 
@@ -574,16 +576,13 @@
   gnc:*report-options*)
 
 (define (customer-options-generator)
-  (options-generator (list ACCT-TYPE-RECEIVABLE) GNC-OWNER-CUSTOMER
-                     (_ "Invoice") #f))
+  (options-generator (list ACCT-TYPE-RECEIVABLE) GNC-OWNER-CUSTOMER #f))
 
 (define (vendor-options-generator)
-  (options-generator (list ACCT-TYPE-PAYABLE) GNC-OWNER-VENDOR
-                     (_ "Bill") #t))
+  (options-generator (list ACCT-TYPE-PAYABLE) GNC-OWNER-VENDOR #t))
 
 (define (employee-options-generator)
-  (options-generator (list ACCT-TYPE-PAYABLE) GNC-OWNER-EMPLOYEE
-                     (_ "Expense Report") #t))
+  (options-generator (list ACCT-TYPE-PAYABLE) GNC-OWNER-EMPLOYEE #t))
 
 (define (string-expand string character replace-string)
   (define (car-line chars)
