@@ -135,6 +135,24 @@
 (define gnc:html-barchart-subtitle
   (record-accessor <html-barchart> 'subtitle))
 
+;; Note: Due to Bug726449 the input string's non-printable control
+;;       characters must translated to HTML format tags BEFORE
+;;       or WHEN calling this function.
+;;       AND:
+;;       To ensure that the generated subtitle doesn't contain any
+;;       unescaped quotes or backslashes, all strings must be freed
+;;       from those by calling jqplot-escape-string.
+;;       Otherwise we're opening the gates again for bug 721768.
+;;
+;;       Example: "\n" must be translated to "<br /> to introduce
+;;                a line break into the chart subtitle.
+;;
+;;       Example call:
+;;         (gnc:html-barchart-set-subtitle! chart
+;;           (string-append "Bgt:"
+;;                          (jqplot-escape-string (number->string bgt-sum))
+;;                          "<br /> Act:" ;; line break in the chart sub-title
+;;                          (jqplot-escape-string (number->string act-sum))))
 (define gnc:html-barchart-set-subtitle!
   (record-modifier <html-barchart> 'subtitle))
 
@@ -341,12 +359,12 @@
                          (push "var d")
                          (push series-index)
                          (push " = [];\n")))
-         (series-data-add (lambda (series-index x y)
+         (series-data-add (lambda (series-index date y)
                          (push (string-append
                                "  d"
                                (number->string series-index)
                                ".push(["
-                               (number->string x)
+                               "\"" date "\""
                                ", "
                                (number->string y)
                                "]);\n"))))
@@ -367,10 +385,12 @@
             (push (gnc:html-js-include "jqplot/jquery.min.js"))
             (push (gnc:html-js-include "jqplot/jquery.jqplot.js"))
             (push (gnc:html-js-include "jqplot/jqplot.barRenderer.js"))
-            (push (gnc:html-js-include "jqplot/jqplot.categoryAxisRenderer.js"))
+            (push (gnc:html-js-include "jqplot/jqplot.cursor.js"))
+            (push (gnc:html-js-include "jqplot/jqplot.dateAxisRenderer.js"))
             (push (gnc:html-js-include "jqplot/jqplot.highlighter.js"))
             (push (gnc:html-js-include "jqplot/jqplot.canvasTextRenderer.js"))
             (push (gnc:html-js-include "jqplot/jqplot.canvasAxisTickRenderer.js"))
+
             (push (gnc:html-css-include "jqplot/jquery.jqplot.css"))
 
             (push "<div id=\"")(push chart-id)(push "\" style=\"width:")
@@ -386,15 +406,17 @@
             (if (and data (list? data))
               (let ((rows (length data))
                     (cols 0))
-                (let loop ((col 0) (rowcnt 1))
+                (let loop ((col 0) (rowcnt 0))
                   (series-data-start col)
                   (if (list? (car data))
                       (begin 
                         (set! cols (length (car data)))))    
                   (for-each
                     (lambda (row)
-                      (series-data-add col rowcnt
+                      (if (< rowcnt rows)
+                        (series-data-add col (list-ref (gnc:html-barchart-row-labels barchart) rowcnt)
                                        (ensure-numeric (list-ref-safe row col)))
+                      )
                       (set! rowcnt (+ rowcnt 1)))
                     data)
                   (series-data-end col (list-ref-safe (gnc:html-barchart-col-labels barchart) col))
@@ -423,7 +445,7 @@
                    },
                    axes: {
                        xaxis: {
-                           renderer: $.jqplot.CategoryAxisRenderer,
+                           renderer:$.jqplot.DateAxisRenderer,
                            tickRenderer: $.jqplot.CanvasAxisTickRenderer,
                            tickOptions: {
                                angle: -30,
@@ -434,8 +456,9 @@
                            autoscale: true,
                        },
                    },
-                   highlighter: {
-                       tooltipContentEditor: formatTooltip,
+                   cursor:{
+                       show: true,
+                       zoom: true
                    }
                 };\n")
 
@@ -452,9 +475,9 @@
 
             (if subtitle
               (begin 
-                (push "  options.title += \" (")
-                (push (jqplot-escape-string subtitle))
-                (push ")\";\n")))
+                (push "  options.title += \" <br />")
+                (push subtitle)
+                (push "\";\n")))
 
             (if (and (string? x-label) (> (string-length x-label) 0))
               (begin 
@@ -466,15 +489,6 @@
                 (push "  options.axes.yaxis.label = \"")
                 (push y-label)
                 (push "\";\n")))
-            (if (and (string? row-labels) (> (string-length row-labels) 0))
-              (begin 
-                (push "  options.axes.xaxis.ticks = [")
-                (for-each (lambda (val)
-                        (push "\"")
-                        (push val)
-                        (push "\","))
-                    (gnc:html-barchart-row-labels barchart))
-                (push "];\n")))
 
 
             (push "$.jqplot.config.enablePlugins = true;")
