@@ -35,6 +35,10 @@
 
 (gnc:module-load "gnucash/report/report-system" 0)
 
+;; included since Bug726449
+(use-modules (ice-9 regex)) ;; for regexp-substitute/global, used by jpqplot
+(load-from-path "html-jqplot.scm") ;; for jqplot-escape-string
+
 ;; The option names are defined here to 1. save typing and 2. avoid
 ;; spelling errors. The *reportnames* are defined here (and not only
 ;; once at the very end) because I need them to define the "other"
@@ -454,8 +458,8 @@ developing over time"))
                              (if do-intervals?
                                  (_ "%s to %s")
                                  (_ "Balances %s to %s"))
-                             (gnc-print-date from-date-tp)
-                             (gnc-print-date to-date-tp)))
+                             (jqplot-escape-string (gnc-print-date from-date-tp))
+                             (jqplot-escape-string (gnc-print-date to-date-tp))))
              (gnc:html-barchart-set-width! chart width)
              (gnc:html-barchart-set-height! chart height)
              
